@@ -34,5 +34,21 @@ print(idx)
 if idx == -1: idx = None
 sout(filtered_ft.data[idx])
 
+# 高速合計関数 (2項演算で集計) [ftable]
+res = ft.csum(0, 2, "score")
+print(res)
+
+# 合計ではない2項演算 (max等) も可能
+res = ft.csum(0, 2, "score", lambda a, b: max(a, b))	# 高速合計関数 (2項演算で集計)
+print(res)
+
+# 集計対象の値がレコード値そのものではなく、少し加工が必要な場合
+res = ft.csum(	# 高速合計関数 (2項演算で集計)
+	0, 2,
+	lambda rec: len(rec["name"]),
+	lambda a, b: max(a, b)
+)
+print(res)
+
 # ランダムなレコードを選定 (seed固定) [ftable]
 print(ft.rget(2))
